 --[[
Simulations for the Mono Lake problem
Compare the results of different scenarios of water export from Mono Lake to Los Angeles

]]--
tmepath = os.getenv("TME_PATH_1_3_0")
package.path = package.path .. ";"..tmepath.."/contrib/viewerlib/?.lua;"..tmepath.."/contrib/terrameaddons/?.lua"

local view = require ("viewer")
local util = require ("util")
dofile ("MonoLakeComplete.lua")



-- these are the possible policy scenarios
-- what will be the simulated outcomes in each case?

scenarios = {
    policies    = { highExport    =  100, 
                    middleExport  =   50, 
                    lowExport     =   25,  
                    verylowExport =   10, 
                    noExport      =    0 },
	outcomes    = { highExport    = 6378,   
                    middleExport  = 6378, 
                    lowExport     = 6378,  
                    verylowExport = 6378, 
                    noExport      = 6378 }
}

--- create the different monoLake simulations
simulations   = {}
for k, v in pairs(scenarios.policies) do
    -- create a simulation instance
    simulations [k]  = util.clone (__monoLakeModel)
    -- each simulation uses a different policy 
    simulations[k].policy.waterExport = scenarios.policies[k]
end

-- create the plot to visualise the results
scenarios.plot = view.Plot {
    subject    = Cell (scenarios.outcomes),
    attributes = {"highExport", "middleExport", "lowExport", "verylowExport", "noExport"}, 
    title      = "MonoLake - Elevation Scenarios", 
	xLabel     = "years", 
	yLabel     = "Elevation (feet)"
    } 

-- create the timer for the model
scenarios.timer = Timer {
	Event{time = 1, period = 1, action = function(e)
		for k, v in pairs (simulations) do
				changes(simulations[k])
				scenarios.outcomes[k] = simulations[k].outcomes.elevation
        end
		scenarios.plot.subject:notify(e:getTime())
		end}
}

-- run the model for 50 years
scenarios.timer:execute (50)




