tmepath = os.getenv("TME_PATH_1_3_0")
package.path = package.path .. ";"..tmepath.."/contrib/viewerlib/?.lua;"..tmepath.."/contrib/terrameaddons/?.lua"

local view = require ("viewer")

-- Mono Lake first model --

function createPlot (model)

    model.plot = view.Plot {
                    subject =  Cell (model.stocks),
                    attributes = {"waterVolume"},
                    title      = "Mono Lake Water Volume",
                    xLabel     = "years",
                    yLabel     = "KAF (kilo acre-feet)"
	}
	model.plot.subject:notify(0) 

end
------------------
function createTimer (model)

	model.timer = Timer {
		Event{time = 1, period = 1, action = function(e)
			changes(model)    -- 
			model.plot.subject:notify(e:getTime()) 
		end}
	}
end
-------------------

function changes (model)

    model.flows.precipitation = model.variables.surfaceArea * model.params.precipitationRate
    
    model.flows.evaporation   = model.variables.surfaceArea * model.params.evaporationRate

	model.stocks.waterVolume  = model.stocks.waterVolume
                                + model.flows.precipitation
                                - model.flows.evaporation
                                + model.flows.runoff    
                                + model.flows.otherIn
                                - model.flows.export
                                - model.flows.otherOut

	if (model.stocks.waterVolume <= 0 ) then
		model.stocks.waterVolume = 0
	end

end

-----------------

function run (model, time)
	model.timer:execute (time)
end


---------
model = {
    -- stocks and flows are expressed in KAF (kilo acre-feet)
	stocks        = { waterVolume    = 2228}, 
    flows         = { 
                      runoff         = 150, 
                      evaporation    =    0, 
                      precipitation  =    0, 
                      export         =  100,
                      otherIn        =   47.6, 
                      otherOut       =   33.6
                    },
                      
	variables     = { surfaceArea    =   39},
	params        = { 
                      precipitationRate = 0.667, 
                      evaporationRate   = 3.75, 
					}
}

createPlot  (model)
createTimer (model)
-----
run (model, 40) 




