tmepath = os.getenv("TME_PATH_1_3_0")
package.path = package.path .. ";"..tmepath.."/contrib/viewerlib/?.lua;"..tmepath.."/contrib/terrameaddons/?.lua"

local view = require ("viewer")

-- Mono Lake second  model --

--- Data for surface area and elevation (Table 4.1 - in Ford's book - first edition)

waterObsL     = {0,    1000,  2000, 3000, 4000, 5000, 6000, 7000, 8000}   -- KAF
surfaceObsL   = {0,    24.7,  35.3, 48.6, 54.3, 57.2, 61.6, 66.0, 69.9}   -- KA
elevationObsL = { 6224, 6335, 6369, 6392, 6412, 6430, 6447, 6463, 6477}   -- feet

-- 
function estimateSurfaceArea  (waterVolume)

	a = 8.1414177963836043E-01
	b = 2.5222522481624796E-02
	c = -3.8848123899271551E-06
	d = 2.2744107985861461E-10

	local surfaceArea = a + b*waterVolume + c*waterVolume^2 + d*waterVolume^3 

	return surfaceArea

end

function estimateElevation (waterVolume)

	a = 6.2344545468507940E+03
	b = 9.6353533955755757E-02
	c = -1.6848484772520475E-05
	d = 1.0858585974826696E-09

	local elevation = a + b*waterVolume + c*waterVolume^2 + d*waterVolume^3 

	return elevation
end


function createPlot (model)

    model.plot = view.Plot {
                    subject =  Cell (model.outcomes),
                    attributes = {"elevation"},
                    title      = "Mono Lake Elevation",
                    xLabel     = "years",
                    yLabel     = "Feet"
	}
	model.plot.subject:notify(0) 

end
------------------
function createTimer (model)

	model.timer = Timer {
		Event{time = 1, period = 1, action = function(e)
			changes(model)    -- 
			model.plot.subject:notify(e:getTime()) 
		end}
	}
end
-------------------

function changes (model)
    
    model.flows.precipitation = estimateSurfaceArea  (model.stocks.waterVolume) * model.params.precipitationRate

	model.flows.evaporation   = estimateSurfaceArea  (model.stocks.waterVolume) * model.params.evaporationRate

	model.stocks.waterVolume  = model.stocks.waterVolume
                                + model.flows.precipitation
                                - model.flows.evaporation
                                + model.flows.runoff    
                                + model.flows.otherIn
                                - model.flows.export
                                - model.flows.otherOut

	if (model.stocks.waterVolume <= 0 ) then
		model.stocks.waterVolume = 0
	end
    
    model.outcomes.elevation = estimateElevation (model.stocks.waterVolume)

end

-----------------

function run (model, time)
	model.timer:execute (time)
end


---------
model = {
    -- stocks and flows are expressed in KAF (kilo acre-feet)
    outcomes      = { elevation      = 6378 },
	stocks        = { waterVolume    = 2228 }, 
    flows         = { 
                      runoff         = 150, 
                      evaporation    =    0, 
                      precipitation  =    0, 
                      export         =  100,
                      otherIn        =   47.6, 
                      otherOut       =   33.6
                    },
                      
	variables     = { surfaceArea    =   39},
	params        = { 
                      precipitationRate = 0.667, 
                      evaporationRate   = 3.75, 
					}
}

createPlot  (model)
createTimer (model)
-----
run (model, 40) 




